## 国债实际收益率曲线利率

接口：us_trycr

描述：国债实际收益率曲线利率

限量：单次最大可获取2000行数据，可循环获取

权限：用户积累120积分可以使用，积分越高频次越高。具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| date | str | N | 日期 （YYYYMMDD格式，下同） |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |
| fields | str | N | 指定输出字段 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| date | str | Y | 日期 |
| y5 | float | Y | 5年期 |
| y7 | float | Y | 7年期 |
| y10 | float | Y | 10年期 |
| y20 | float | Y | 20年期 |
| y30 | float | Y | 30年期 |

接口调用

```python
pro = ts.pro_api()

df = pro.us_trycr(start_date='20180101', end_date='20200327')


#获取5年期和20年期数据
df = pro.us_trycr(start_date='20180101', end_date='20200327', fields='y5,y20')
```

数据样例

```python
date     y5     y7    y10    y20    y30
0     20200327  -0.13  -0.20  -0.22  -0.12  -0.03
```